# To recreate figures and tables in the appendix simply run this script
# Outputs figures as pdf files and tables as tex files
# Figure and table numbering as in article

##### Load required packages, read in dataset #####
library(stargazer)
df <- read.csv('data.csv')


##### Compute results for Table A.1 #####
value = numeric(8)
value[1] <- mean(df$age)
value[2] <- mean(df$gender) * 100
value[3] <- mean(df$education>5) * 100
value[4] <- median(df$income[df$income!=98])
value[5] <- mean(df$party_id==2) * 100
value[6] <- mean(df$party_id==1) * 100
value[7] <- mean(df$party_id==37) * 100
value[8] <- mean(df$party_id==21) * 100
sstat <- data.frame(Sample=value)
row.names(sstat) <- c('Age (Mean)', 'Male', 'College or above',
                      'Median Monthly Household Income',
                      'Support DPP', 'Support KMT', 'Support TPP',
                      'Support NPP')
stargazer(sstat, summary = FALSE, out = 'tableA1.tex', out.header = T)

##### Compute results for Table A.2 #####
value = matrix(numeric(21), nrow=7, ncol=3)
for (i in 1:3){
  dft = df[df$group == i,]
  dft$nat_id <- recode(dft$nat_id, '1' = 1, '2' = 0, '3' = 0, '98' = 0)
  value[1,i] = mean(dft$age)
  value[2,i] = mean(dft$gender) * 100
  value[3,i] = mean(dft$education>5) * 100
  value[4,i] = median(dft$income[dft$income!=98])
  value[5,i] = mean(dft$pan_green) * 100
  value[6,i] = mean(dft$pan_blue) * 100
  value[7,i] = mean(dft$nat_id) * 100
}
baltab <- data.frame(value)
colnames(baltab) <- c('Control', 'Rumour', 'Rebuttal')
row.names(baltab) <- c('Age (Mean)', 'Male', 'College or above',
                      'Median Monthly Household Income',
                      'Support Pan-Green', 'Support Pan-Blue', 'Exclusively Taiwanese Identity')
stargazer(baltab, summary = FALSE, out = 'tableA2.tex', out.header = T)